@@ -74,6 +74,7 @@ gboolean     ExitAll = FALSE;
 char        *ImageToDisplay = NULL;
 gboolean     FirstStart = TRUE;
 gboolean     ImportPhotos = FALSE;
+gboolean     UseViewer = FALSE;
 
 static gboolean        view_comline_catalog = FALSE;
 static gboolean        view_single_image = FALSE;
@@ -92,6 +93,9 @@ struct poptOption options[] = {
 	{ "import-photos", '\0', POPT_ARG_NONE, &ImportPhotos, 0,
 	  N_("Automatically import digital camera photos"),
 	  0 },
+	{ "viewer", '\0', POPT_ARG_NONE, &UseViewer, 0,
+	  "Use the viewer mode to view single images",
+	  0 },
 	{ NULL, '\0', 0, NULL, 0 }
 };
 
@@ -384,8 +388,9 @@ initialize_data (poptContext pctx)
 
 	/* Default windows icon */
 
-	gtk_window_set_default_icon_name ("gthumb");
 	init_icon_pixbufs ();
+	g_set_application_name (_("gThumb"));
+	gtk_window_set_default_icon_name ("gthumb");
 
 	/**/
 
@@ -422,7 +427,7 @@ initialize_data (poptContext pctx)
 		else
 			tmp1 = g_strdup (argv[i]);
 
-		tmp2= remove_special_dirs_from_path (tmp1);
+		tmp2 = remove_special_dirs_from_path (tmp1);
 
 		if (! g_path_is_absolute (tmp2))
 			path = g_strconcat (current_dir, "/", tmp2, NULL);
@@ -607,17 +612,26 @@ prepare_app (void)
 		return;
 	}
 
-	if (! view_comline_catalog && (n_dir_urls == 0) && (n_file_urls == 0)) {
-		if (ImportPhotos)
-			preferences_set_startup_location (NULL);
-		open_browser_window (NULL, !ImportPhotos, use_factory, app, &env);
-	}
+	if (ImportPhotos) {
+		if (use_factory)
+			GNOME_GThumb_Application_import_photos (app, &env);
+		else 
+			gth_browser_activate_action_file_camera_import (NULL, NULL);
 
-	if (view_single_image) {
+	} else if (! view_comline_catalog 
+	    && (n_dir_urls == 0) 
+	    && (n_file_urls == 0)) {
+		open_browser_window (NULL, TRUE, use_factory, app, &env);
+
+	} else if (view_single_image) {
 		if (use_factory && eel_gconf_get_boolean (PREF_SINGLE_WINDOW, FALSE))
 			GNOME_GThumb_Application_load_image (app, file_urls[0], &env);
-		else
-			open_viewer_window (file_urls[0], use_factory, app, &env);
+		else {
+			if (UseViewer)
+				open_viewer_window (file_urls[0], use_factory, app, &env);
+			else
+				open_browser_window (file_urls[0], TRUE, use_factory, app, &env);
+		}
 
 	} else if (view_comline_catalog) {
 		char *catalog_uri;
@@ -669,18 +683,6 @@ prepare_app (void)
 }
 
 
-static gboolean 
-check_whether_to_import_photos (gpointer data) 
-{
-	if (ImportPhotos 
-	    && (first_window != NULL) 
-	    && GTH_IS_BROWSER (first_window))
-		gth_browser_activate_action_file_camera_import (NULL, GTH_BROWSER (first_window));
-
-	return FALSE;
-}
-
-
 int 
 main (int   argc, 
       char *argv[])
@@ -719,7 +721,6 @@ main (int   argc,
 	initialize_data (pctx);
 	poptFreeContext (pctx);
 	prepare_app ();
-	g_idle_add (check_whether_to_import_photos, NULL);
 
 	gtk_main ();
 
@@ -1023,13 +1024,10 @@ G_CONST_RETURN char *
 get_stock_id_for_uri (const char *uri)
 {
 	const char *stock_id;
-	char       *home_uri;
-
-	home_uri = g_strconcat ("file://", g_get_home_dir (), NULL);
 
 	if (strcmp (uri, g_get_home_dir ()) == 0) 
 		stock_id = GTK_STOCK_HOME;
-	else if (strcmp (uri, home_uri) == 0) 
+	else if (strcmp (uri, get_home_uri ()) == 0) 
 		stock_id = GTK_STOCK_HOME;
 	else if (folder_is_film (uri))
 		stock_id = GTHUMB_STOCK_FILM;
@@ -1040,8 +1038,6 @@ get_stock_id_for_uri (const char *uri)
 	else
 		stock_id = GTK_STOCK_OPEN;
 
-	g_free (home_uri);
-
 	return stock_id;
 }
 
@@ -1051,17 +1047,14 @@ get_icon_for_uri (GtkWidget  *widget,
 		  const char *uri)
 {
 	const char *stock_id = NULL;
-	char       *home_uri;
 	int         menu_size;
 
 	menu_size = get_folder_pixbuf_size_for_list (widget);
 
-	home_uri = g_strconcat ("file://", g_get_home_dir (), NULL);
 	if (strcmp (uri, g_get_home_dir ()) == 0) 
 		return get_fs_icon (ICON_NAME_HOME, menu_size);
-	else if (strcmp (uri, home_uri) == 0) 
+	else if (strcmp (uri, get_home_uri ()) == 0) 
 		return get_fs_icon (ICON_NAME_HOME, menu_size);
-	g_free (home_uri);
 
 	if ((strcmp (uri, "file://") == 0) || (strcmp (uri, "/") == 0)) 
 		return get_fs_icon (ICON_NAME_HARDDISK, menu_size);
